#
# spec file for package shadowsocks-libev
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libver 2

Name:           shadowsocks-libev
Version:        3.1.3
Release:        lp150.1.4
Summary:        Libev port of Shadowsocks
License:        GPL-3.0+
Group:          Productivity/Networking/Web/Proxy
Url:            https://github.com/shadowsocks/shadowsocks-libev
Source0:        https://github.com/shadowsocks/shadowsocks-libev/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-config.json
Source2:        %{name}-client.service
Source3:        %{name}-server.service
Source4:        %{name}-tunnel.service
Source5:        %{name}-nat.service
Source6:        %{name}-manager.service
Source7:        %{name}-redir.service
BuildRequires:  libtool
BuildRequires:  mbedtls-devel
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libsodium) >= 1.0.4
BuildRequires:  pkgconfig(openssl)
%if 0%{?fedora} >= 24
BuildRequires:  pkgconfig
%else
BuildRequires:  pkg-config
%endif
%if 0%{?fedora} == 24
BuildRequires:  ghostscript-core
%endif
BuildRequires:  asciidoc
BuildRequires:  systemd
BuildRequires:  xmlto
Recommends:     simple-obfs
%{?systemd_requires}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
shadowsocks-libev is a lightweight secured SOCKS5 proxy
for embedded devices and low-end boxes.

%package -n lib%{name}%{libver}
Summary:        Libev port of Shadowsocks
Group:          System/Libraries

%description -n lib%{name}%{libver}
shadowsocks-libev is a lightweight secured SOCKS5 proxy
for embedded devices and low-end boxes.

This package provides libraries for it.

%package doc
Summary:        Documents for shadowsocks-libev
Group:          Documentation/HTML
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
shadowsocks-libev is a lightweight secured SOCKS5 proxy
for embedded devices and low-end boxes.

This package provides Documents for it.

%package devel
Summary:        Development headers for shadowsocks-libev
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{libver} = %{version}

%description devel
shadowsocks-libev is a lightweight secured SOCKS5 proxy
for embedded devices and low-end boxes.

This package provides development headers for it.

%prep
%setup -q

%build
%configure --enable-shared
make %{?_smp_mflags} V=1

%install
%make_install

rm -rf %{buildroot}/%{_libdir}/*.la

install -d %{buildroot}%{_sysconfdir}/shadowsocks/
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/shadowsocks/

install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE4} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE5} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE6} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE7} %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcshadowsocks-libev-client
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcshadowsocks-libev-server
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcshadowsocks-libev-manager
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcshadowsocks-libev-nat
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcshadowsocks-libev-redir
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcshadowsocks-libev-tunnel

%pre
%{service_add_pre %{name}-server.service %{name}-client.service \
    %{name}-manager.service %{name}-nat.service %{name}-redir.service \
    %{name}-tunnel.service}

%post
%{service_add_post %{name}-server.service %{name}-client.service \
    %{name}-manager.service %{name}-nat.service %{name}-redir.service \
    %{name}-tunnel.service}

%preun
%{service_del_preun %{name}-server.service %{name}-client.service \
    %{name}-manager.service %{name}-nat.service %{name}-redir.service \
    %{name}-tunnel.service}

%postun
%{service_del_postun %{name}-server.service %{name}-client.service \
    %{name}-manager.service %{name}-nat.service %{name}-redir.service \
    %{name}-tunnel.service}

%post -n lib%{name}2 -p /sbin/ldconfig

%postun -n lib%{name}2 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc Changes README.md COPYING AUTHORS
%dir %{_sysconfdir}/shadowsocks
%config(noreplace) %{_sysconfdir}/shadowsocks/%{name}-config.json
%{_bindir}/ss-local
%{_bindir}/ss-redir
%{_bindir}/ss-server
%{_bindir}/ss-tunnel
%{_bindir}/ss-manager
%{_bindir}/ss-nat
%{_mandir}/man8/%{name}.8.gz
%{_mandir}/man1/ss-*.1.gz
%{_sbindir}/rcshadowsocks-libev-*
%{_unitdir}/%{name}-*.service

%files -n lib%{name}%{libver}
%defattr(-,root,root)
%{_libdir}/lib%{name}.so.*

%files doc
%defattr(-,root,root)
%dir %{_datadir}/doc/%{name}
%doc %{_datadir}/doc/%{name}/*.html

%files devel
%defattr(-,root,root)
%{_includedir}/shadowsocks.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so

%changelog
* Sat Jan 20 2018 hillwood@opensuse.org
- Update version to 3.1.3
  * Fix a bug in UDP relay.
* Sat Dec 30 2017 jengelh@inai.de
- Instad of removing static libs after the fact, do not even build
  them in the first place.
- Fix RPM groups and spelling errors in the description.
* Fri Dec 29 2017 hillwood@opensuse.org
- Update to 3.1.2
  * Fix a bug in DNS resolver.
  * Add new TFO API support.
- Drop fix-Command-Execution-in-ss-manager.patch. Merged by upstream.
* Tue Oct 31 2017 hillwood@opensuse.org
- Add fix-Command-Execution-in-ss-manager.patch
  * Fix boo#1065619 and CVE-2017-15924
* Thu Sep 28 2017 hillwood@opensuse.org
- Fix Request tag.
* Tue Sep 19 2017 hillwood@opensuse.org
- Update to 3.1.0
  * Replace libudns with libc-ares.
- Merge libbloom, libcork and libipset.
* Thu Aug 10 2017 hillwood@opensuse.org
- Update to 3.0.8
  * Refine the ping-pong bloom filter.
  * Minor bug fixes by @vfreex, @vlolteanu and @jackyyf.
* Thu Jul 20 2017 hillwood@opensuse.org
- Set simple-obfs by Recommends.
* Thu Jul 20 2017 hillwood@opensuse.org
- Update to 3.0.7
  * Fix a bug with AEAD ciphers.
  * Refine ACL support by @blackgear.
  * Refine manager mode by @mengxd.
  * Fix a potential memory leak by @vlolteanu.
* Tue Apr 18 2017 hillwood@opensuse.org
- Update to 3.0.5
  * Drop dependencies of OpenSSL and PolarSSL.
  * Deprecate OTA (One-Time-Auth).
  * Add new ciphers for SIP004: aes-128-gcm, aes-192-gcm, aes-256-gcm,
    chacha20-poly1305 and chacha20-ietf-poly1305.
  * Refine SIP003 to support standalone mode of obfsproxy.
  * Fix a crashe when using stream ciphers.
  * Fix a protocol bug in AEAD ciphers. (SIP004)
  * Allow setting keys directly. (SIP006)
  * Add session key for AEAD. (SIP007)
  * Replace nonce cache with a ping-pong bloom filter.
  * Add CMake files by @wenerme.
  * Support TCP Fast Open in ss-redir by @lqs.
  * Support TOS/DESCP in ss-redir by @sduponch.
  * Refine MPTCP by @sduponch.
  * Fix a bug of TCP Fast Open in ss-redir.
* Tue Dec  6 2016 jengelh@inai.de
- Use a single call to %%service_*
* Mon Dec  5 2016 hillwood@opensuse.org
- Fix %%pre, %%post, %%preun and %%postun.
* Mon Dec  5 2016 hillwood@opensuse.org
- Add system scripts for ss-redir, ss-tunnel, ss-manager and ss-nat.
- Split doc package.
* Fri Dec  2 2016 hillwood@opensuse.org
- Update to 2.5.6
  * Add outbound ACL for server by @kimw.
  * Refine log format by @kimw.
  * Refine attack detection.
  * Fix a bug of auto blocking mechanism.
  * Fix TCP Fast Open on macOS.
  * Fix a bug of UDP relay mode of ss-local.
  * Refine ACL feature with hostname support.
  * Add HTTP/SNI parser for ss-local/ss-redir.
  * Fix several bugs of the command line interface.
  * Add aes-128/192/256-ctr ciphers.
  * Add option MTU for UDP relay.
  * Add MultiPath TCP support.
- Fix spec for Fedora.
* Fri Dec  2 2016 hillwood@opensuse.org
- update to 2.4.8
  * Fix a security bug.
  * Refine memory management.
  * Minor bug fixes.
  * Fix a potential memory leak.
  * Fix some compiler related issues.
  * Fix build issues on OpenWRT.
  * Reduce the latency of redir mode.
  * Update manual pages by @kimw.
  * Enhance UDP relay mode by @wongsyrone.
  * Add ss-nat, a helper script to set up NAT rules for ss-redir,
    from @aa65535.
  * Fix several issues for debian package by @rogers0.
  * Update manual pages with asciidoc by @anonymous-contributor.
  * Fix issues of bind_address option by @tim-le.
* Sun Oct 11 2015 hillwood@linuxfans.org
- Update to 2.4.0
  * Refine the one-time authentication.
- Changes of 2.3.3 and 2.3.2
  * Minor bug fixes.
- Changes of 2.3.1
  * Fix an issue of connection cache of UDP relay.
  * Add support of one time authentication for header verification.
* Sat Aug 22 2015 i@marguerite.su
- update version 2.3.0
  * add manager mode to support multi-user and traffic stat
- changes in 2.2.3
  * Fix some issues for multi-destination UDP relay
* Thu Jun 25 2015 i@marguerite.su
- update version 2.2.2
  * fix the timer of UDP relay
* Fri Jun  5 2015 i@marguerite.su
- update version 2.2.1
  * fix an issue of UDF relay.
- changes in 2.2.0
  * add TPROXY support for redir mode.
* Sun Mar 15 2015 i@marguerite.su
- systemd service:
  * restart on failure instead of abort
  * enable tcp fast open
* Fri Feb 13 2015 i@marguerite.su
- update version 2.1.4
  * add acl support to server mode
* Sat Jan 17 2015 i@marguerite.su
- update version 2.0.8
  * minor bug fixes
- changes in 1.6.3~2.0.7
  * refine documents
  * implement a real asyncchronous DNS resolver
  * fix some issues with MinGW
  * refine ss-local, ss-tunnel, and ss-redir
  * fix an issue in redir mode
* Sat Jan  3 2015 i@marguerite.su
- update version 1.6.2
  * minor bugfix
- changes in 1.5.0~1.6.1
  * Support to build static or shared library.
  * Refine the cache size of UDPRelay.
  * Fix a bug introduced by fast open.
  * Handle signals properly.
  * Fix log on Win32.
  * Add salsa20 and chacha20 support
* Sat Oct 25 2014 i@marguerite.su
- update version 1.4.8
  * Fix a bug of tcp fast open.
- changes in 1.4.7
  * Add a new encryptor rc4-md5
* Fri Aug 22 2014 i@marguerite.su
- update version 1.4.6
  * minor bugfix release
* Fri May  2 2014 i@marguerite.su
- initial version 1.4.5
  * Fix the compatibility issue of udprelay.
  * Enhance asyncns to reduce the latency.
- add shadowsocks-libev-config.json
  * random ports, random passwords.
  * strongest encryption method
- add systemd services
